Measure ingredients list: has at least three unit types: energy: food calories, joules biological activity: IU mass + mass equivalents: grams { "name": "Energy", "measures": { "energy": { "per package": { "listed": [ "3082.660", "kcal" ], "food calories": { "decimal string": "3082.660", "fraction string": "154133/50" }, "joules": { "decimal string": "12897849.440", "fraction string": "322446236/25" } } } } }, { "name": "Vitamin D (D2 + D3), International Units", "measures": { "biological activity": { "per package": { "listed": [ "0.000", "IU" ], "IU": { "decimal string": "0.000", "fraction string": "0" } } } } }, { "name": "Carbohydrate, by difference", "measures": { "mass + mass equivalents": { "per package": { "listed": [ "64.877", "g" ], "grams": { "decimal string": "64.877", "fraction string": "456528486851663599/7036874417766400" } } } } }